* Construction of individual-level dataset on income and wealth consistent with national account aggregates


clear


* CREATE WEALTH VARIABLES BY CAPITALIZING INCOME TAX RETURNS


* Input capitalization factors and converts into macros
foreach yr of numlist $years { 
*insheet using "$parameters", delimiter(";") clear names
insheet using "$parameters", clear names
keep if yr==`yr'
foreach var of varlist _all {
local `var'=`var'
}


use "$dirsmall/small`yr'.dta", clear

#delimit;	
local income_irs "income waginc divinc kginc intinc intexm estinc schcincp rylinc scorpinc scorpinc2
partpinc partpinc2 rentincp othinc mortded realestatetax peninc penincnt penira oldexm intdedoth partlinc rentincl scorlinc schcincl scorinc rentinc partinc schcinc itemded married item taxunits adults20"; 
#delimit cr
keep `income_irs' dweght

* Housing wealth
gen rental=0
replace rental=rentincp*`frentincp'+estinc*`festhous'  /*  Tenant-occupied housing + trust housing wealth */
gen ownergross=0
replace ownergross=realestatetax*`fresttax' /* Gross owner-occupied housing wealth */
gen ownermort=0
replace ownermort=-mortded*`fmortded' /* Mortgages on owner-occupied housing wealth */
* For non-itemizers: assume everyone has same amount of owner-occupied housing and mortgages (computed so as to match FRB totals)
* To be improved if one wants to look at bottom90 in more details
quietly: su ownergross [w=dweght]
local tothousbot=`ttrestw'-r(sum)/10e10
quietly: su dweght if ownergross==0
replace ownergross=`tothousbot'/(r(sum)/10e10) if ownergross==0
quietly: su ownermort [w=dweght]
local totmortbot=`ttmortw'-r(sum)/10e10
quietly: su dweght if ownermort==0
replace ownermort=`totmortbot'/(r(sum)/10e10) if ownermort==0
gen housing=rental+ownergross+ownermort
drop mortded realestatetax

* Business assets (excluding S corp): 0 value when negative business income
gen partw=0 /* Partnerships (including fraction of partship in trusts) */
replace partw=partpinc2*`fpartpinc2'+estinc*`festbus' 
gen soleprop=0 /* Sole prop (includes royalty-generating assets) */
replace soleprop=(schcincp+rylinc)*`fschcincp' 
gen business=partw+soleprop

* Equities (including S corp)
gen scorw=0
replace scorw=scorpinc2*`fscorpinc2'
gen equitykg=(divinc+kginc)*`fdivkg'+estinc*`festdivkg'+scorw /* Equities obtained by capitalizing div+KG and div+KG estate income. */
gen equity=divinc*`fdivinc'+estinc*`festdiv'+scorw /* Equities obtained by capitalizing div and div estate income. */
gen kgpos=max(0,kginc)

* Taxable fixed income claims
gen taxbond=intinc*`fintinctax'+estinc*`festint' /* Includes fraction of fixed income in estates */

* Pensions
* SAEZ: to increase pension concentration to match SCF, assume that bottom 60% wage earners have no pension wealth and that pension wealth proportional to wages above percentile 60
* SAEZ: loading more pension wealth on wages (instead of pensions) actually decreases pension concentration
* 40% proportional to wages (for top 60% wage earners, bottom 40 has 0 pension), 60% proportional to pension distributions 
cumul waginc [w=dweght] if waginc>0, gen(rankwage)
replace rankwage=1-(1-rankwage)*`fracfiling'
replace rankwage=0 if rankwage==.
gen wagetop60=0 
* original has .4 in rank wage and does not remove bottom wage portion 
egen aux=min(waginc) if rankwage>0.5
replace wagetop60=waginc-aux if rankwage>0.5 
cap drop aux
quietly: su wagetop60 [w=dweght] 
local sumwagetop60=r(sum)/10e10
gen totpeninc=peninc+penincnt
quietly: su totpeninc [w=dweght] 
local sumtotpeninc=r(sum)/10e10
* original has .4 and .6 weights here
gen pensionlab=wagetop60*(`ttpenw'+`ttpeniraw')*0.4/`sumwagetop60'+totpeninc*(`ttpenw'+`ttpeniraw')*0.6/`sumtotpeninc' 
drop wagetop60 rankwage totpeninc

* Munis since 1987
gen muni=0
replace muni=intexm*`fintexm' if `yr'>1986 /* Municipal securities interest only available from 1987 on; pre-87 muni added below */

* Distribution of wealth0 = wealth for which we have info in income tax returns in all years (= excludes muni, non mortgage debt, currency)
egen wealth0=rsum(housing business equity taxbond pensionlab)
egen wealth0kg=rsum(housing business equitykg taxbond pensionlab)
cumul wealth0 [w=dweght], gen(rank0)
replace rank0=1-(1-rank0)*`fracfiling'



* WEALTH VARIABLES FOR WHICH NO INCOME AVAILABLE: MUNIS PRE 87, CURRENCY, NON-MORTGAGE DEBT


* General method: assume muni (resp. currency, etc.) as a % of wealth0 is constant by wealth group, 
* with groups = bottom 90, top 10 to top 5, etc., as defined in cumul:
* (NB: non-mortgage debt has always the good sign, but currency and muni can be negative)
matrix define cumul=(-1, .90, .95, .99, .995, .999, .9999, 1)
local nbgroup=colsof(cumul)
#delimit;
matrix nontax = 
(.0337, .0564, .2597, .1085, .2267, .1819, .1329 \  							/* Share of ttmuni held by diff wealth groups in 87 */
.4, .15, .22, .06, .08, .06, .03 \  											/* Share of currency: anchored on SCF, assume constant over time */
.9, .025, .036, .01,  .014, .009, .006 \										/* Share of non-mortgage debt: approximate distribution based on pre-TRA86 and SCF  */
.773, .059, .08, .022,  .032, .021, .012);									    /* Share of non-mortgage debt: 1962-86 average of pre-TRA86 non-mort debt shares  */
#delimit cr																
matrix colnames nontax = bot90 top10to5 top5to1 top1to05 top05to01 top01to001 top001
matrix rownames nontax = shmuni shcurrency shnonmort shnonmortpre87
gen currency=0
gen nonmort=0
local jj=1
while `jj'<`nbgroup' {
	quietly: su wealth0 [w=dweght] if (cumul[1,`jj']<rank0)&(rank0<=cumul[1,`jj'+1])
	replace muni=    wealth0*nontax[1,`jj']*`ttmuni'/(r(sum)/10e10) if (cumul[1,`jj']<rank0)&(rank0<=cumul[1,`jj'+1])&`yr'<1987
	replace currency=wealth0*nontax[2,`jj']*`ttcurrency'/(r(sum)/10e10) if (cumul[1,`jj']<rank0)&(rank0<=cumul[1,`jj'+1])
	quietly: su wealth0 [w=dweght] if (cumul[1,`jj']<rank0)&(rank0<=cumul[1,`jj'+1])&wealth0>=0
	replace nonmort= wealth0*nontax[3,`jj']*`ttothdebt'/(r(sum)/10e10) if (cumul[1,`jj']<rank0)&(rank0<=cumul[1,`jj'+1])&wealth0>=0 
	local jj=`jj'+1
}
gen bond=taxbond+muni
gen fix=taxbond+muni+currency+nonmort
gen debt=nonmort+ownermort /* excluded mortgages on tenant-occupied housing for which no info available */



* ALTERNATIVE CAPITALIZATION TECHNIQUES


* Bond wealth allowing for heterogenous bond returns
* Assume the top 1% of income earners has the  10-yrs Treasury yield on its taxable fixed income claims
cumul income [w=dweght], gen(rankinc) 
replace rankinc=1-(1-rankinc)*`fracfiling'
gen bondheter=intinc*`fintop1'+estinc*`festint'
replace bondheter=intinc*`fintbottom99'+estinc*`festint' if rankinc<=0.99 
gen fixheter=bondheter+muni+currency+nonmort

* Simplified pension wealth (proportional to distributions only)
gen pension=(peninc+penincnt)*`fpen' 
replace pension=penira*`fpenira'+(peninc+penincnt-penira)*`fpen' if `yr'>1987 /* Since 1988, different factor for IRAs and non IRAs */

* Non-mortgage debt based on pre-86 non-mortgage interest deductions + avg 62-86 distribution for post 86 
gen nonmortpretra=0
if `yr'<1987 {
replace nonmortpretra=-intdedoth*`fnonmort' if rank0>=.9
quietly: su nonmortpretra [w=dweght]
local nonmortpretrab90=`ttothdebt'-r(sum)/10e10
quietly: su wealth0 [w=dweght] if rank0<.9&wealth0>=0
local avgmortpretrab90=`nonmortpretrab90'/(r(sum)/10e10)
replace nonmortpretra=wealth0*`avgmortpretrab90' if rank0<.9&wealth0>=0
drop intdedoth
}
if `yr'>1986 {
local jj=1
while `jj'<`nbgroup' {
	quietly: su wealth0 [w=dweght] if (cumul[1,`jj']<rank0)&(rank0<=cumul[1,`jj'+1])&wealth0>=0
	replace nonmortpretra= wealth0*nontax[4,`jj']*`ttothdebt'/(r(sum)/10e10) if (cumul[1,`jj']<rank0)&(rank0<=cumul[1,`jj'+1])&wealth0>=0
	local jj=`jj'+1
}
}
gen fixpretra=taxbond+muni+currency+nonmortpretra
drop wealth0 wealth0kg rank0

* INCOME CATEGORIES FROM TAX RETURNS
gen labinc=waginc+peninc
gen businc=schcinc+scorinc+partinc
gen capinc=divinc+intinc+rentinc+estinc+rylinc

* INCOME MATCHING NIPA TOTALS (INCLUDING PRODUCT TAXES), _na SUFFIX
* Business income (mix of labor and capital)
* Capital component = return on business wealth; labor=residual
gen kbus_na=business*`yieldbus'
gen lbus_na=(partpinc+schcincp+rylinc)*`blowlbus'
gen bus_na=kbus_na+lbus_na


* Capital income
* Method: attribute asset-specific return to each asset
* Capital income is not exactly matching total NIPA because of non-profits and gov interest
gen div_na=equity*`yieldeq'
gen divkg_na=equitykg*`yieldeq'
gen int_na=fix*`yieldfix'
gen rent_na=housing*`yieldhous'
gen pen_na=pensionlab*`yieldpen'
gen kinc_na=div_na+int_na+rent_na+kbus_na+pen_na
gen kinckg_na=divkg_na+int_na+rent_na+kbus_na+pen_na

* Labor income
gen wag_naold=waginc*`blowwag' 
* sum wag_naold wag_na [w=dweght]
gen linc_na=wag_na+lbus_na

* Total income (kg suffix = corporate profit obtained by applying yield to equities obtained by capitalizing div+KG)
gen inc_na=kinc_na+linc_na
gen inckg_na=kinckg_na+linc_na



save "dinafiles/usdina`yr'(SZ).dta", replace
}




